'use strict';

var React = require('react');

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function Carousel(props) {
    var _a = React.useReducer(function (state, action) {
        switch (action.type) {
            case "NEXT":
                return {
                    active: state.nextActive,
                    nextActive: (state.nextActive + 1) % props.slides.length
                };
            case "CUSTOM":
                return {
                    active: state.nextActive,
                    nextActive: action.index
                };
            default:
                throw new Error();
        }
    }, { active: -1, nextActive: 0 }), state = _a[0], dispatch = _a[1];
    var timerId1 = React.useRef();
    var timerId2 = React.useRef();
    React.useEffect(function () {
        clearTimeout(timerId1.current);
        timerId1.current = setTimeout(function () {
            dispatch({ type: "NEXT" });
        }, props.duration || 1000);
        return function () { return clearTimeout(timerId1.current); };
    }, [state.nextActive, props.duration]);
    function setIndex(index) {
        clearTimeout(timerId1.current);
        clearTimeout(timerId2.current);
        dispatch({ type: "CUSTOM", index: index });
        timerId1.current = setTimeout(function () {
            dispatch({ type: "BRING_NEXT" });
        }, props.duration || 1000);
    }
    return (React.createElement("div", { style: styles.container, className: "animated-carousel-container" },
        props.slides.map(function (slide, index) { return (React.createElement("div", { key: index, style: __assign(__assign({}, styles.item), getAnimationStyle({
                index: index,
                activeIndex: state.active,
                nextActiveIndex: state.nextActive,
                animationType: props.animationType,
                duration: props.animationDuration,
                timingFunction: props.animationTimingFunction,
                animationDelay: props.animationDelay
            })), className: "animated-carousel-item" }, slide)); }),
        props.withNavigation && (React.createElement("div", { className: "animated-carousel-dots", style: { zIndex: 1 } }, props.slides.map(function (slide, index) { return (React.createElement("button", { key: "" + index, className: "animated-carousel-dot " + (index === state.nextActive ? "active" : ""), onClick: function (e) { return setIndex(index); } })); })))));
}
var styles = {
    container: {
        position: "relative",
        overflow: "hidden",
        width: "100%",
        height: "100%"
    },
    item: {
        position: "absolute",
        width: "100%",
        height: "100%",
        objectFit: "cover"
    }
};
function getAnimationStyle(_a) {
    var index = _a.index, activeIndex = _a.activeIndex, nextActiveIndex = _a.nextActiveIndex, animationType = _a.animationType, duration = _a.duration, timingFunction = _a.timingFunction, animationDelay = _a.animationDelay;
    var style;
    switch (animationType) {
        case "FADE":
            style = {
                opacity: nextActiveIndex === index ? 1 : 0
            };
            break;
        case "SLIDE":
            style = {
                transform: "translateX(" + (index - nextActiveIndex) * 100 + "%)"
            };
            break;
        case "ZOOM":
            style = {
                transform: "scale(" + (nextActiveIndex === index ? 1 : 2) + ")",
                opacity: nextActiveIndex === index ? 1 : 0
            };
            break;
        default:
            style = {
                opacity: nextActiveIndex === index ? 1 : 0,
                transition: "none"
            };
    }
    return __assign(__assign({ transition: "all " + (duration || 700) / 1000 + "s  " + (timingFunction ||
            "cubic-bezier(0.1, 0.99, 0.1, 0.99)") + " " + (animationDelay || 100) / 1000 + "s" }, style), { zIndex: nextActiveIndex === index ? 1 : 0 });
}

module.exports = Carousel;
